import React from 'react';
import { Avatar, Menu, Spin } from 'antd';
import { LogoutOutlined, FormOutlined } from '@ant-design/icons';
import { history, connect } from 'umi';
import { defaultAvatar } from '@/utils/utils';
import ChangePassword from '@/components/ChangePassword'
import HeaderDropdown from '../HeaderDropdown';
import styles from './index.less';

class AvatarDropdown extends React.Component {
  state = {
    showPassword: false,
  }

  onMenuClick = (event) => {
    const { key } = event;

    if (key === 'logout') {
      const { dispatch } = this.props;

      if (dispatch) {
        dispatch({
          type: 'login/logout',
        });
      }

      return;
    }

    if (key === 'password') {
      this.setState({ showPassword: true })
    }
  };

  render() {
    const {
      currentUser = {
        avatar: '',
        userName: '',
      },
    } = this.props;

    const menuHeaderDropdown = (
      <Menu className={styles.menu} selectedKeys={[]} onClick={this.onMenuClick}>
        <Menu.Item key="password">
          <FormOutlined />
          修改密码
        </Menu.Item>
        <Menu.Item key="logout">
          <LogoutOutlined />
          退出登录
        </Menu.Item>
        <ChangePassword
          visible={this.state.showPassword}
          onVisibleChange={(v) => this.setState({ showPassword: v })}
          onFinish={() => this.setState({ showPassword: false })}
        />
      </Menu>
    );
    return currentUser && currentUser.userName ? (
      <HeaderDropdown overlay={menuHeaderDropdown}>
        <span className={`${styles.action} ${styles.account}`}>
          <Avatar
            size="small"
            className={styles.avatar}
            src={ currentUser.avatar || defaultAvatar }
            alt="avatar"
          />
          <span className={`${styles.name} anticon`}>{currentUser.userName}</span>
        </span>
      </HeaderDropdown>
    ) : (
      <span className={`${styles.action} ${styles.account}`}>
        <Spin
          size="small"
          style={{
            marginLeft: 8,
            marginRight: 8,
          }}
        />
      </span>
    );
  }
}

export default connect(({ user }) => ({
  currentUser: user.currentUser,
}))(AvatarDropdown);
