import React, { useEffect, useState } from 'react';
import { connect, history } from 'umi';

import { PageContainer } from '@ant-design/pro-layout';
import Container from '@/components/Container';
import { Input, Form, Button, notification } from 'antd';
import ProForm, { ProFormText, ProFormTextArea, ProFormSelect } from '@ant-design/pro-form';
import request from '@/utils/request';

const { Search } = Input;
const VisitEdit = (props) => {
  const { id, schoolId } = props.location.query;

  const [searchLoading, setSearchLoading] = useState(false);

  const [form] = Form.useForm();

  const getData = (id) => {
    if (id) {
      request(`/student/${id}`)
        .then((res) => {
          form.setFieldsValue(res);
          setSearchLoading(false);
        })
        .catch((e) => {
          setSearchLoading(false);
        });
    } else {
      // this.setState({ data: [] });
    }
  };

  useEffect(() => {
    if (id) {
      if (id) {
        request(`/medical-log/${id}`)
          .then((res) => {
            form.setFieldsValue(res);
            setSearchLoading(false);
          })
          .catch((e) => {
            setSearchLoading(false);
          });
      } else {
        // this.setState({ data: [] });
      }
    }
  }, [id]);

  const onSearch = (value) => {
    if (value) {
      getData(value);
      setSearchLoading(true);
    } else {
      // this.setState({ data: [] });
    }
  };

  const handleSubmit = (value) => {
    request('/medicalLog', { method: 'post', data: { schoolId, ...value } })
      .then(() => {
        notification.success({ message: '新建成功' });
        history.go('-1');
      })
      .catch((e) => {
        notification.error({ message: e.message });
      });
  };
  return (
    <PageContainer
      header={{
        extra: [
          <Button key="1" onClick={() => history.go('-1')}>
            返回
          </Button>,
        ],
      }}
    >
      <Container>
        <ProForm form={form} submitter={!id} onFinish={handleSubmit}>
          {!id && (
            <Search
              placeholder="请输入学号"
              loading={searchLoading}
              style={{ width: 200, marginBottom: '20px' }}
              onSearch={onSearch}
            />
          )}
          <ProForm.Group layout="inline" title="就诊信息">
            <ProFormText
              label="姓名"
              placeholder="输入名称"
              name="name"
              fieldProps={{ bordered: !id, readOnly: !!id }}
              rules={[{ required: true, message: '请填写名称' }]}
            />

            <ProFormSelect
              options={[
                {
                  value: 1,
                  label: '男',
                },
                {
                  value: 2,
                  label: '女',
                },
              ]}
              name="sex"
              label="性别"
              fieldProps={{ bordered: !id, open: id ? false : undefined }}
              rules={[{ required: true, message: '请选择性别' }]}
            />

            <ProFormText
              label="学号"
              placeholder="输入学号"
              name="studentId"
              fieldProps={{ bordered: !id, readOnly: !!id }}
              rules={[{ required: true, message: '请填写学号' }]}
            />

            <ProFormText
              label="联系方式"
              placeholder="输入联系方式"
              name="phone"
              fieldProps={{ bordered: !id, readOnly: !!id }}
              rules={[{ required: true, message: '请填写联系方式' }]}
            />
          </ProForm.Group>

          <ProFormTextArea
            label="诊断报告"
            placeholder="输入诊断报告"
            name="attchment"
            fieldProps={{ readOnly: !!id, rows: 10 }}
            rules={[{ required: true, message: '请填写诊断报告' }]}
            style={{ width: '100%' }}
          />
        </ProForm>
      </Container>
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(VisitEdit);
