import React, { useEffect } from 'react';
import ProForm, {
  ProFormText,
  ProFormRadio,
} from '@ant-design/pro-form';
import UploadImage from '@/components/UploadImage';
import request from '@/utils/request';
import { notification, Form } from 'antd';

export default (props) => {
  const [form] = Form.useForm();

  const handleSubmit = (values) => {
    const data = {
      targetType: 'post',
      targetId: props.post.postId,
      ...props.post?.shareSetting || {},
      ...values,
    }

    if (!data.serialNo) {
      // 新增
      return request('/share-setting', { method: 'post', data })
        .then((res) => {
          props.onChange(res);
          notification.success({ message: '操作成功' });
        })
        .catch((e) => {
          notification.error({ message: e.message });
          return Promise.reject(e.message);
        });
    }

    // 编辑
    return request(`/share-setting/${data.serialNo}`, { method: 'put', data })
    .then((res) => {
      props.onChange(res);
      notification.success({ message: '操作成功' });
    })
    .catch((e) => {
      notification.error({ message: e.message });
      return Promise.reject(e.message);
    });
  };

  useEffect(() => {
    if (props.post?.shareSetting && props.post?.shareSetting.serialNo) {
      form.setFieldsValue(props.post?.shareSetting);
    }
  }, [props.post?.shareSetting, form]);

  return (
    <ProForm form={form} onFinish={handleSubmit}>
      <ProFormText
        label="分享标题"
        placeholder="请输入分享标题"
        name="title"
        rules={[{ required: true, message: '请填写分享标题' }]}
      />

      <Form.Item name="imageUrl" label="分享图" placeholder="请设置分享图">
        <UploadImage />
      </Form.Item>

      <ProFormRadio.Group
        label="状态"
        name="status"
        options={[
          {
            label: '禁用',
            value: 0,
          },
          {
            label: '启用',
            value: 1,
          },
        ]}
      />
    </ProForm>
  );
};
