import { LockOutlined, UserOutlined } from '@ant-design/icons';
import { Alert } from 'antd';
import React from 'react';
import ProForm, { ProFormText } from '@ant-design/pro-form';
// import { useIntl, connect, FormattedMessage } from 'umi';
import { connect } from 'umi';
import md5 from 'md5';

import styles from './index.less';

const LoginMessage = ({ content }) => (
  <Alert
    style={{
      marginBottom: 24,
    }}
    message={content}
    type="error"
    showIcon
  />
);

const Login = (props) => {
  const { userLogin = {}, submitting } = props;
  const { status } = userLogin;
  // const intl = useIntl();

  const handleSubmit = (values) => {
    const { dispatch } = props;
    dispatch({
      type: 'login/login',
      payload: { ...values, password: md5(values.password) },
    });
  };

  return (
    <div className={styles.main}>
      <ProForm
        initialValues={{
          autoLogin: true,
        }}
        submitter={{
          render: (_, dom) => dom.pop(),
          submitButtonProps: {
            loading: submitting,
            size: 'large',
            style: {
              width: '100%',
            },
          },
        }}
        onFinish={(values) => {
          handleSubmit(values);
          return Promise.resolve();
        }}
      >
        {status === 'error' && !submitting && (
          <LoginMessage
            content="账户或密码错误"
            // content={intl.formatMessage({
            //   id: 'pages.login.accountLogin.errorMessage',
            //   defaultMessage: '账户或密码错误（admin/ant.design)',
            // })}
          />
        )}
        <ProFormText
          name="userName"
          fieldProps={{
            size: 'large',
            prefix: <UserOutlined className={styles.prefixIcon} />,
          }}
          // placeholder={intl.formatMessage({
          //   id: 'pages.login.username.placeholder',
          //   defaultMessage: '用户名: admin or user',
          // })}
          placeholder="用户名:"
          rules={[
            {
              required: true,
              message: '请输入用户名!',
              // message: (
              //   <FormattedMessage
              //     id="pages.login.username.required"
              //     defaultMessage="请输入用户名!"
              //   />
              // ),
            },
          ]}
        />
        <ProFormText.Password
          name="password"
          fieldProps={{
            size: 'large',
            prefix: <LockOutlined className={styles.prefixIcon} />,
          }}
          // placeholder={intl.formatMessage({
          //   id: 'pages.login.password.placeholder',
          //   defaultMessage: '密码: ant.design',
          // })}
          placeholder="密码:"
          rules={[
            {
              required: true,
              // message: (
              //   <FormattedMessage
              //     id="pages.login.password.required"
              //     defaultMessage="请输入密码！"
              //   />
              // ),
              message: '请输入密码!',
            },
          ]}
        />
      </ProForm>
    </div>
  );
};

export default connect(({ login, loading }) => ({
  userLogin: login,
  submitting: loading.effects['login/login'],
}))(Login);
